@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 UNKNOWN_EVENT = 0x00
 START_EVENT_V3 = 0x01
 QUERY_EVENT = 0x02
@@ -26,11 +28,11 @@ UPDATE_ROWS_EVENT_V1 = 0x18
 WRITE_ROWS_EVENT_V1 = 0x17
 INCIDENT_EVENT = 0x1a
 HEARTBEAT_LOG_EVENT = 0x1b
-IGNORABLE_LOG_EVENT= 0x1c
-ROWS_QUERY_LOG_EVENT= 0x1d
-WRITE_ROWS_EVENT = 0x1e
-UPDATE_ROWS_EVENT = 0x1f
-DELETE_ROWS_EVENT = 0x20
-GTID_LOG_EVENT= 0x21
-ANONYMOUS_GTID_LOG_EVENT= 0x22
-PREVIOUS_GTIDS_LOG_EVENT= 0x23
+IGNORABLE_LOG_EVENT = 0x1c
+ROWS_QUERY_LOG_EVENT = 0x1d
+WRITE_ROWS_EVENT_V2 = 0x1e
+UPDATE_ROWS_EVENT_V2 = 0x1f
+DELETE_ROWS_EVENT_V2 = 0x20
+GTID_LOG_EVENT = 0x21
+ANONYMOUS_GTID_LOG_EVENT = 0x22
+PREVIOUS_GTIDS_LOG_EVENT = 0x23
\ No newline at end of file
