@@ -14,6 +14,7 @@ if (major, minor) < (2, 7):
 else:
     base = unittest.TestCase
 
+
 class PyMySQLReplicationTestCase(base):
     def ignoredEvents(self):
         return []
@@ -74,5 +75,5 @@ class PyMySQLReplicationTestCase(base):
         self.execute("RESET MASTER")
         if self.stream is not None:
             self.stream.close()
-        self.stream = BinLogStreamReader(connection_settings=self.database,
+        self.stream = BinLogStreamReader(self.database, server_id=1024,
                                          ignored_events=self.ignoredEvents())
