@@ -13,6 +13,12 @@ class TestBasicBinLogStreamReader(base.PyMySQLReplicationTestCase):
     def ignoredEvents(self):
         return [GtidEvent]
 
+    def test_allowed_event_list(self):
+        self.assertEqual(len(self.stream._allowed_event_list(None, None, False)), 10)
+        self.assertEqual(len(self.stream._allowed_event_list(None, None, True)), 9)
+        self.assertEqual(len(self.stream._allowed_event_list(None, [RotateEvent], False)), 9)
+        self.assertEqual(len(self.stream._allowed_event_list([RotateEvent], None, False)), 1)
+
     def test_read_query_event(self):
         query = "CREATE TABLE test (id INT NOT NULL AUTO_INCREMENT, data VARCHAR (50) NOT NULL, PRIMARY KEY (id))"
         self.execute(query)
@@ -60,9 +66,9 @@ class TestBasicBinLogStreamReader(base.PyMySQLReplicationTestCase):
 
     def test_connection_stream_lost_event(self):
         self.stream.close()
-        self.stream = BinLogStreamReader(connection_settings=self.database,
-                                         blocking=True,
-                                         ignored_events=self.ignoredEvents())
+        self.stream = BinLogStreamReader(
+            self.database, server_id=1024, blocking=True,
+            ignored_events=self.ignoredEvents())
 
         query = "CREATE TABLE test (id INT NOT NULL AUTO_INCREMENT, data VARCHAR (50) NOT NULL, PRIMARY KEY (id))"
         self.execute(query)
@@ -84,10 +90,10 @@ class TestBasicBinLogStreamReader(base.PyMySQLReplicationTestCase):
             event = self.stream.fetchone()
             self.assertIsNotNone(event)
 
-    def test_filtering_events(self):
+    def test_filtering_only_events(self):
         self.stream.close()
-        self.stream = BinLogStreamReader(connection_settings=self.database,
-                                         only_events=[QueryEvent])
+        self.stream = BinLogStreamReader(
+            self.database, server_id=1024, only_events=[QueryEvent])
         query = "CREATE TABLE test (id INT NOT NULL AUTO_INCREMENT, data VARCHAR (50) NOT NULL, PRIMARY KEY (id))"
         self.execute(query)
 
@@ -95,6 +101,38 @@ class TestBasicBinLogStreamReader(base.PyMySQLReplicationTestCase):
         self.assertIsInstance(event, QueryEvent)
         self.assertEqual(event.query, query)
 
+    def test_filtering_ignore_events(self):
+        self.stream.close()
+        self.stream = BinLogStreamReader(
+            self.database, server_id=1024, ignored_events=[QueryEvent])
+        query = "CREATE TABLE test (id INT NOT NULL AUTO_INCREMENT, data VARCHAR (50) NOT NULL, PRIMARY KEY (id))"
+        self.execute(query)
+
+        event = self.stream.fetchone()
+        self.assertIsInstance(event, RotateEvent)
+
+    def test_filtering_table_event(self):
+        self.stream.close()
+        self.stream = BinLogStreamReader(
+            self.database,
+            server_id=1024,
+            only_events=[WriteRowsEvent],
+            only_tables = ["test_2"])
+
+        query = "CREATE TABLE test_2 (id INT NOT NULL AUTO_INCREMENT, data VARCHAR (50) NOT NULL, PRIMARY KEY (id))"
+        self.execute(query)
+        query = "CREATE TABLE test_3 (id INT NOT NULL AUTO_INCREMENT, data VARCHAR (50) NOT NULL, PRIMARY KEY (id))"
+        self.execute(query)
+
+        self.execute("INSERT INTO test_2 (data) VALUES ('alpha')")
+        self.execute("INSERT INTO test_3 (data) VALUES ('alpha')")
+        self.execute("INSERT INTO test_2 (data) VALUES ('beta')")
+        self.execute("COMMIT")
+        event = self.stream.fetchone()
+        self.assertEqual(event.table, "test_2")
+        event = self.stream.fetchone()
+        self.assertEqual(event.table, "test_2")
+
     def test_write_row_event(self):
         query = "CREATE TABLE test (id INT NOT NULL AUTO_INCREMENT, data VARCHAR (50) NOT NULL, PRIMARY KEY (id))"
         self.execute(query)
@@ -203,7 +241,8 @@ class TestBasicBinLogStreamReader(base.PyMySQLReplicationTestCase):
         if self.stream is not None:
             self.stream.close()
         self.stream = BinLogStreamReader(
-            connection_settings=self.database,
+            self.database,
+            server_id=1024,
             resume_stream=True,
             log_file=log_file,
             log_pos=log_pos,
@@ -223,7 +262,8 @@ class TestBasicBinLogStreamReader(base.PyMySQLReplicationTestCase):
     def test_log_pos_handles_disconnects(self):
         self.stream.close()
         self.stream = BinLogStreamReader(
-            connection_settings=self.database,
+            self.database,
+            server_id=1024,
             resume_stream=False,
             only_events = [FormatDescriptionEvent, QueryEvent, TableMapEvent, WriteRowsEvent, XidEvent]
         )
@@ -363,9 +403,8 @@ class TestGtidBinLogStreamReader(base.PyMySQLReplicationTestCase):
         gtid = self.execute(query).fetchone()[0]
 
         self.stream.close()
-        self.stream = BinLogStreamReader(connection_settings=self.database,
-                                         blocking=True,
-                                         auto_position=gtid)
+        self.stream = BinLogStreamReader(
+            self.database, server_id=1024, blocking=True, auto_position=gtid)
 
         self.assertIsInstance(self.stream.fetchone(), RotateEvent)
         self.assertIsInstance(self.stream.fetchone(), FormatDescriptionEvent)
@@ -420,9 +459,8 @@ class TestGtidBinLogStreamReader(base.PyMySQLReplicationTestCase):
         gtid = self.execute(query).fetchone()[0]
 
         self.stream.close()
-        self.stream = BinLogStreamReader(connection_settings=self.database,
-                                         blocking=True,
-                                         auto_position=gtid)
+        self.stream = BinLogStreamReader(
+            self.database, server_id=1024, blocking=True, auto_position=gtid)
 
         self.assertIsInstance(self.stream.fetchone(), RotateEvent)
         self.assertIsInstance(self.stream.fetchone(), FormatDescriptionEvent)
